import { Directive, HostListener, ChangeDetectorRef, Component, ContentChild, NgModule } from '@angular/core';
import { canvas, ImageDebug, onProcessed, onDetected, decodeSingle } from 'quagga';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class InputRefDirective {
    constructor() {
        this.focus = false;
    }
    /**
     * @return {?}
     */
    onFocus() {
        this.focus = true;
    }
    /**
     * @return {?}
     */
    onBlur() {
        this.focus = false;
    }
}
InputRefDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngx-barcode-input input'
            },] },
];
/** @nocollapse */
InputRefDirective.propDecorators = {
    "onFocus": [{ type: HostListener, args: ['focus',] },],
    "onBlur": [{ type: HostListener, args: ['blur',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgxBarcodeInputComponent {
    /**
     * @param {?} ref
     */
    constructor(ref) {
        this.ref = ref;
        this.barcode = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} result
     * @return {?}
     */
    onProcessed(result) {
        const /** @type {?} */ drawingCtx = canvas.ctx.overlay;
        const /** @type {?} */ drawingCanvas = canvas.dom.overlay;
        if (result) {
            if (result.boxes) {
                drawingCtx.clearRect(0, 0, parseInt(drawingCanvas.getAttribute('width')), parseInt(drawingCanvas.getAttribute('height')));
                result.boxes.filter(function (box) {
                    return box !== result.box;
                }).forEach(function (box) {
                    ImageDebug.drawPath(box, { x: 0, y: 1 }, drawingCtx, { color: 'green', lineWidth: 2 });
                });
            }
            if (result.box) {
                ImageDebug.drawPath(result.box, { x: 0, y: 1 }, drawingCtx, { color: '#00F', lineWidth: 2 });
            }
            if (result.codeResult && result.codeResult.code) {
                ImageDebug.drawPath(result.line, { x: 'x', y: 'y' }, drawingCtx, { color: 'red', lineWidth: 3 });
            }
        }
    }
    /**
     * @param {?} e
     * @return {?}
     */
    onChange(e) {
        if (e.target.files && e.target.files.length) {
            onProcessed((result) => this.onProcessed(result));
            onDetected((result) => this.detectedBarcode(result));
            this.onDecodeSingle(URL.createObjectURL(e.target.files[0]));
        }
    }
    /**
     * @param {?} img_src
     * @return {?}
     */
    onDecodeSingle(img_src) {
        const /** @type {?} */ config = {
            locate: true,
            locator: {
                patchSize: 'medium',
                halfSample: true
            },
            decoder: {
                readers: ['code_128_reader']
            },
            src: img_src
        };
        // Promisify DecodeSingle method from Quagga
        return new Promise((resolve, reject) => {
            decodeSingle(config, result => {
                if (!result || typeof result.codeResult === 'undefined') {
                    reject('Barcode Cannot be Decoded, Please Try a Valid Barcode and/or a Clear Photo of Barcode');
                }
                else {
                    resolve(result.codeResult.code);
                }
            });
        }).catch((error) => {
            console.error(error);
            alert(error);
        });
    }
    /**
     * @param {?} result
     * @return {?}
     */
    detectedBarcode(result) {
        this.barcode = result.codeResult.code;
    }
}
NgxBarcodeInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-barcode-input',
                template: `<div style="float: left;">
  <input type="text" name="barcode" ([ngModel])="barcode" [value]="barcode" placeholder="Barcode Input" autocomplete="off">
  <input type="file" id="file" name="file" class="inputfile" accept="image/*" capture="environment" (change)="onChange($event)">
  <button type="button" style="padding: 4px 4px 0 4px; line-height: 1em;"><label for="file"><span>Take a photo</span></label></button>
</div>

<div style="clear: both;"></div>
<div id="interactive" class="viewport"></div>
`,
                styles: [`#interactive.viewport{width:300px;height:300px;overflow:hidden;padding-top:15px}#interactive.viewport canvas,video{margin-top:-50px;width:300px;height:400px}#interactive.viewport canvas.drawingBuffer,video.drawingBuffer{margin-left:-300px}.inputfile{width:.1px;height:.1px;opacity:0;overflow:hidden;position:absolute;z-index:-1}.inputfile+button,.inputfile+label{cursor:pointer}`]
            },] },
];
/** @nocollapse */
NgxBarcodeInputComponent.ctorParameters = () => [
    { type: ChangeDetectorRef, },
];
NgxBarcodeInputComponent.propDecorators = {
    "input": [{ type: ContentChild, args: [InputRefDirective,] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgxBarcodeInputModule {
}
NgxBarcodeInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgxBarcodeInputComponent, InputRefDirective],
                exports: [NgxBarcodeInputComponent, InputRefDirective]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { NgxBarcodeInputModule, InputRefDirective as ɵb, NgxBarcodeInputComponent as ɵa };
//# sourceMappingURL=ngx-barcode-input.js.map
