import { Directive, HostListener, ChangeDetectorRef, Component, ContentChild, NgModule } from '@angular/core';
import { canvas, ImageDebug, onProcessed, onDetected, decodeSingle } from 'quagga';
import { CommonModule } from '@angular/common';

var InputRefDirective = /** @class */ (function () {
    function InputRefDirective() {
        this.focus = false;
    }
    InputRefDirective.prototype.onFocus = function () {
        this.focus = true;
    };
    InputRefDirective.prototype.onBlur = function () {
        this.focus = false;
    };
    return InputRefDirective;
}());
InputRefDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngx-barcode-input input'
            },] },
];
InputRefDirective.propDecorators = {
    "onFocus": [{ type: HostListener, args: ['focus',] },],
    "onBlur": [{ type: HostListener, args: ['blur',] },],
};
var NgxBarcodeInputComponent = /** @class */ (function () {
    function NgxBarcodeInputComponent(ref) {
        this.ref = ref;
        this.barcode = '';
    }
    NgxBarcodeInputComponent.prototype.ngOnInit = function () { };
    NgxBarcodeInputComponent.prototype.onProcessed = function (result) {
        var drawingCtx = canvas.ctx.overlay;
        var drawingCanvas = canvas.dom.overlay;
        if (result) {
            if (result.boxes) {
                drawingCtx.clearRect(0, 0, parseInt(drawingCanvas.getAttribute('width')), parseInt(drawingCanvas.getAttribute('height')));
                result.boxes.filter(function (box) {
                    return box !== result.box;
                }).forEach(function (box) {
                    ImageDebug.drawPath(box, { x: 0, y: 1 }, drawingCtx, { color: 'green', lineWidth: 2 });
                });
            }
            if (result.box) {
                ImageDebug.drawPath(result.box, { x: 0, y: 1 }, drawingCtx, { color: '#00F', lineWidth: 2 });
            }
            if (result.codeResult && result.codeResult.code) {
                ImageDebug.drawPath(result.line, { x: 'x', y: 'y' }, drawingCtx, { color: 'red', lineWidth: 3 });
            }
        }
    };
    NgxBarcodeInputComponent.prototype.onChange = function (e) {
        var _this = this;
        if (e.target.files && e.target.files.length) {
            onProcessed(function (result) { return _this.onProcessed(result); });
            onDetected(function (result) { return _this.detectedBarcode(result); });
            this.onDecodeSingle(URL.createObjectURL(e.target.files[0]));
        }
    };
    NgxBarcodeInputComponent.prototype.onDecodeSingle = function (img_src) {
        var config = {
            locate: true,
            locator: {
                patchSize: 'medium',
                halfSample: true
            },
            decoder: {
                readers: ['code_128_reader']
            },
            src: img_src
        };
        return new Promise(function (resolve, reject) {
            decodeSingle(config, function (result) {
                if (!result || typeof result.codeResult === 'undefined') {
                    reject('Barcode Cannot be Decoded, Please Try a Valid Barcode and/or a Clear Photo of Barcode');
                }
                else {
                    resolve(result.codeResult.code);
                }
            });
        }).catch(function (error) {
            console.error(error);
            alert(error);
        });
    };
    NgxBarcodeInputComponent.prototype.detectedBarcode = function (result) {
        this.barcode = result.codeResult.code;
    };
    return NgxBarcodeInputComponent;
}());
NgxBarcodeInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-barcode-input',
                template: "<div style=\"float: left;\">\n  <input type=\"text\" name=\"barcode\" ([ngModel])=\"barcode\" [value]=\"barcode\" placeholder=\"Barcode Input\" autocomplete=\"off\">\n  <input type=\"file\" id=\"file\" name=\"file\" class=\"inputfile\" accept=\"image/*\" capture=\"environment\" (change)=\"onChange($event)\">\n  <button type=\"button\" style=\"padding: 4px 4px 0 4px; line-height: 1em;\"><label for=\"file\"><span>Take a photo</span></label></button>\n</div>\n\n<div style=\"clear: both;\"></div>\n<div id=\"interactive\" class=\"viewport\"></div>\n",
                styles: ["#interactive.viewport{width:300px;height:300px;overflow:hidden;padding-top:15px}#interactive.viewport canvas,video{margin-top:-50px;width:300px;height:400px}#interactive.viewport canvas.drawingBuffer,video.drawingBuffer{margin-left:-300px}.inputfile{width:.1px;height:.1px;opacity:0;overflow:hidden;position:absolute;z-index:-1}.inputfile+button,.inputfile+label{cursor:pointer}"]
            },] },
];
NgxBarcodeInputComponent.ctorParameters = function () { return [
    { type: ChangeDetectorRef, },
]; };
NgxBarcodeInputComponent.propDecorators = {
    "input": [{ type: ContentChild, args: [InputRefDirective,] },],
};
var NgxBarcodeInputModule = /** @class */ (function () {
    function NgxBarcodeInputModule() {
    }
    return NgxBarcodeInputModule;
}());
NgxBarcodeInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgxBarcodeInputComponent, InputRefDirective],
                exports: [NgxBarcodeInputComponent, InputRefDirective]
            },] },
];

export { NgxBarcodeInputModule, InputRefDirective as ɵb, NgxBarcodeInputComponent as ɵa };
//# sourceMappingURL=ngx-barcode-input.js.map
